@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-auth
-version: 1.4.12
-id: yesod-auth-1.4.12-4d106a89bc5f54fb1850e8a22c0b22dc
-key: yesod_98MLZSMfUir4669ZKVnpJL
+version: 1.4.13.1
+id: yesod-auth-1.4.13.1-02ce33af0017c100af6587c6e90a960e
+key: yesod_02SIi6douTk6Ivbqi2AdNr
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,13 +20,13 @@ exposed-modules:
     Yesod.Auth.GoogleEmail Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded
 hidden-modules: Yesod.Auth.Routes Yesod.PasswordStore
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.12
-library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.12
-data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.12
-hs-libraries: HSyesod-auth-1.4.12-98MLZSMfUir4669ZKVnpJL
+import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.13.1
+hs-libraries: HSyesod-auth-1.4.13.1-02SIi6douTk6Ivbqi2AdNr
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
-    authenticate-1.3.3-82116eed41342375d6e732a036f13e91
+    authenticate-1.3.3.1-de5806f9d15beccb070a770364a3018e
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -36,24 +36,24 @@ depends:
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
+    cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     email-validate-2.2.0-2cb19fcad74f009f580f5d1a0c1a07e6
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
-    http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
-    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
+    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
+    http-conduit-2.1.9-a114e1e30c63561e9380f63d9f83e5a8
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
+    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
     mime-mail-0.4.11-363f204ae632de52ba204fa0d2f16891
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-    nonce-1.0.2-c0bfd19efc8c42e1c2c83d3a058f813a
-    persistent-2.2.4.1-e7a8900dd9bde9ebb31b88aa3930cc01
-    persistent-template-2.1.6-1493d56e17183452cb446159287a778d
+    nonce-1.0.2-4d1212dfb084a803f723eea311d0a719
+    persistent-2.2.4.1-840a8f388c4f74e927e97d9dd2d8494d
+    persistent-template-2.1.6-6446adcdac00e4cf9aeae54844fe611d
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
@@ -61,10 +61,10 @@ depends:
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-    yesod-core-1.4.19-b6ec8d224ea1c49c36126eee73b10ab6
-    yesod-form-1.4.6-6e5c019f77bbb31f3f8cbc24ba3a758a
-    yesod-persistent-1.4.0.3-c6542cb45d0d37a797eae519cf194b16
+    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+    yesod-core-1.4.20.1-8dce2c1559c72b98aae15f98b85f32e0
+    yesod-form-1.4.7-6556fa2dbba4c60b35adfc5077eb6d41
+    yesod-persistent-1.4.0.4-05d2e78a4f4be2f611edc21702f1c928
 haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
 haddock-html: /usr/share/doc/haskell-yesod-auth/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
